# eric7.EricWidgets.EricPlainTextDialog

Module implementing a dialog to show some plain text.

### Global Attributes

None

### Classes

EricPlainTextDialog | Class implementing a dialog to show some plain text.

### Functions

None

## EricPlainTextDialog

Class implementing a dialog to show some plain text.

### Derived from

QDialog, Ui_EricPlainTextDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricPlainTextDialog | Constructor
on_copyButton_clicked | Private slot to copy the text to the clipboard.
toPlainText | Public method to get the plain text.

### Static Methods

None

#### EricPlainTextDialog (Constructor)

EricPlainTextDialog(title="", text="", readOnly=True, parent=None)

Constructor

title (str (optional))
  title of the dialog (defaults to "")
text (str (optional))
  text to be shown (defaults to "")
readOnly (bool (optional))
  flag indicating a read-only dialog (defaults to True)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### EricPlainTextDialog.on_copyButton_clicked

on_copyButton_clicked()

Private slot to copy the text to the clipboard.

#### EricPlainTextDialog.toPlainText

toPlainText()

Public method to get the plain text.

Return:
  contents of the plain text edit

Return Type:
  str

Up